#
# spec file for package vpnc
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if ! %{defined _rundir}
%define _rundir %{_localstatedir}/run
%endif
Name:           vpnc
Version:        0.5.3r550
Release:        4.4
Summary:        A Client for Cisco VPN concentrator
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Security
URL:            http://svn.unix-ag.uni-kl.de/vpnc/branches/vpnc-nortel
Source:         %{name}-%{version}.tar.bz2
# only for checkin warnings...
Source1:        checkout_svn.sh
Source2:        %{name}.conf
Source3:        %{name}.service
# most ugly hack ever
Patch1:         vpnc-restart-after-timeout.diff
BuildRequires:  gnutls
BuildRequires:  libgcrypt-devel
BuildRequires:  libgnutls-devel
BuildRequires:  pkg-config
Requires:       %{_bindir}/sed
Requires:       /sbin/ip
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} >= 1210
BuildRequires:  pkgconfig(systemd)
%endif

%description
A VPN client compatible with Cisco's EasyVPN equipment.

Cisco 3000, IOS routers, PIX/ASA Zecurity Appliances, and
Juniper/Netscreen as well as Nortel Contivity (experimental).

Supported Authentications: Pre-Shared-Key + XAUTH, Pre-Shared-Key
Supported IKE DH-Groups: dh1 dh2 dh5 Supported Hash Algo (IKE/IPSEC):
md5 sha1 Supported Encryptions (IKE/IPSEC): (null) (1des) 3des aes128
aes192 aes256 Perfect Forward Secrecy: nopfs dh1 dh2 dh5

It runs entirely in userspace and uses the TUN/TAP driver for access.

%prep
%autosetup -p1 -n %{name}

%build
export CFLAGS="%{optflags}"
make PREFIX=/usr %{?_smp_mflags}

%install
mkdir -p %{buildroot}/%{_rundir}/vpnc
make install \
	DESTDIR=%{buildroot} \
	PREFIX=/usr
rm -rfv %{buildroot}%{_datadir}/doc/vpnc
%if 0%{?suse_version} >= 1210
install -D -m 0644 $RPM_SOURCE_DIR/%{name}.service %{buildroot}/%{_unitdir}/%{name}@.service
install -D -m 0644 $RPM_SOURCE_DIR/%{name}.conf %{buildroot}/%{_tmpfilesdir}/%{name}.conf
%endif
sed -i -e '1c#!/usr/bin/perl' %{buildroot}%{_bindir}/pcf2vpnc

%pre
%if 0%{?suse_version} >= 1210
%service_add_pre %{name}@.service
%endif

%post
%if 0%{?suse_version} >= 1210
%tmpfiles_create %{_tmpfilesdir}/%{name}.conf
%service_add_post %{name}@.service
%endif

%preun
%if 0%{?suse_version} >= 1210
%service_del_preun %{name}@.service
%endif

%postun
%if 0%{?suse_version} >= 1210
%service_del_postun %{name}@.service
%endif

%files
%defattr(-,root,root)
%attr(0600,root,root) %config(noreplace) %ghost %{_sysconfdir}/%{name}/default.conf

%ghost %{_rundir}/vpnc
%dir %{_sysconfdir}/%{name}
%{_sysconfdir}/%{name}/vpnc-script
%{_sbindir}/vpnc
%{_sbindir}/vpnc-disconnect
%{_bindir}/cisco-decrypt
%{_bindir}/pcf2vpnc
%{_mandir}/man1/cisco-decrypt.1.*
%{_mandir}/man1/pcf2vpnc.1.*
%{_mandir}/man8/vpnc.8.*
%if 0%{?suse_version} >= 1210
%{_unitdir}/%{name}@.service
%{_tmpfilesdir}/%{name}.conf
%endif
%doc ChangeLog README TODO VERSION
%license COPYING

%changelog
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Thu May  7 2020 pgajdos@suse.com
- %%{_libexecdir} now expands to /usr/libexec, so do not use it
  where /usr/lib was intended; use %%{_tmpfilesdir} in this case
  instead
* Tue Feb 19 2019 suse+build@de-korte.org
- Fix references path below legacy directory /var/run -> /run
- Run %%tmpfiles_create macro in %%post
- Fix env-script-interpreter error
* Wed Nov 12 2014 idonmez@suse.com
- Update to svn r550
  * Bugfixes and many openSUSE patches merged
- Remove vpnc-no-build-dates.patch, vpnc-pidfile-path.diff and
  vpnc-add-name-to-stderr-log.diff. Merged upstream.
* Tue Sep 23 2014 mpluskal@suse.com
- Add unit file
- Fix building for SLE_11_SP3
- Clean specfile
* Fri May 16 2014 tittiatcoke@gmail.com
- use %%_rundir if available
* Thu May  9 2013 crrodriguez@opensuse.org
- packages must not install files in /etc/tmpfiles.d/
  which is reserved for the system administrator.
* Sun Nov 25 2012 tittiatcoke@gmail.com
- Ensure that on every boot the directory /var/run/vpnc is
  created (bnc#773379)
- Removed patch work-with-netconfig.patch as this is now included
  upstream
* Tue Oct  9 2012 tittiatcoke@gmail.com
- Update to rev 517 of nortel branch
  - Check Vendor vs nat traversal mode
  - Fix compatibility with Solaris 10 /bin/sh
- Package now owns the /var/run/vpnc directory (bnc#773379)
* Sat Jan 14 2012 seife+obs@b1-systems.com
- update to rev 512 of nortel branch
  - mostly fixes to vpnc-script and typos / compiler warnings
  - obsoletes "bugfix.diff"
* Wed Jan  4 2012 seife+obs@b1-systems.com
- Add "vpnc: " prefix to stderr logmessages
* Wed Jan  4 2012 seife+obs@b1-systems.com
- change License field to GPL-2.0+ (bnc#731966)
* Mon Nov 28 2011 seife+obs@b1-systems.com
- update to rev 481 of nortel branch
  - better version of vpnc-ipid.diff upstream
  - various code cleanups
  - log to stdout instead of syslog in debug mode
* Fri Nov 18 2011 seife+obs@b1-systems.com
- fix pidfile writing (/var/run/vpnc does not necessarily exist)
* Wed Nov  9 2011 seife+obs@b1-systems.com
- update to rev 472 of nortel branch
  - memleak fix improved and upstreamed
* Tue Nov  8 2011 seife+obs@b1-systems.com
- update to rev 469 of nortel branch
  - fritzbox compatibility patches improved and upstreamed
- add patch to fix memleaks, to be upstreamed
- add a very ugly patch to restart vpnc after lifetime expired
* Fri Nov  4 2011 seife+obs@b1-systems.com
- update to rev 464 of nortel branch
  - fix some endianness issues
  - improve handling of some isakmp delete payloads
  - fix some format string warnings from debug messages and
    strict aliasing warnings
- add URL to spec file
- add "checkout_svn.sh" to generate a new tarball from SVN
* Fri Nov  4 2011 seife+obs@b1-systems.com
- add another patch from the vpnc mailing list for fritzbox
  compatibility (vpnc-fritzbox2.diff)
* Thu Nov  3 2011 seife+obs@b1-systems.com
- add patch to make vpnc work against fritzbox vpn:
  - ignore invalid(?) ike lifetime attribute instead of asserting
  - ignore ISAKMP_PAYLOAD_N message instead of aborting
* Mon Oct 24 2011 jengelh@medozas.de
- Resolve 'Error: either "to" is duplicate, or "ipid" is a
  garbage.' message when connecting and inability to not be able
  to send packets due to the gateway route being absent.
* Fri Aug 26 2011 tittiatcoke@gmail.com
- Added patch to change /etc/resolv.conf with the help of netconfig
  (bnc#712435)
* Thu Aug  4 2011 tittiatcoke@gmail.com
- Resolved rpmlint warning non-ghost-in-var-run.
  - Files in /var/run/vpnc are not required as that they will be
    created automatically
* Thu Sep  9 2010 cristian.rodriguez@opensuse.org
- makeman.pl internal scripts adds local build time, change
  it to the source man template filemtime instead, so we avoid
  republishing this package every month.
* Mon Jan  4 2010 crrodriguez@opensuse.org
- use RPM_OPT_FLAGS and -fno-strict-aliasing
* Sun Dec 20 2009 tittiatcoke@gmail.com
- Added a fix for bug (bno#555577)
  * This fix would take network routes send by the VPN gateway
    into account
* Sun Nov  1 2009 tittiatcoke@gmail.com
- Update to 0.5.3 svn 449
  + Add support for Nortel proprietary UDP NATT.
* Fri Oct 30 2009 tittiatcoke@gmail.com
- Update to 0.5.3 svn 447
  + Fix memory leak (Thanks to Bin Li)
  + Merge in Nortel branch
  + Extract "default domain" value and pass it to vpnc-script
  + Implements Nortel "server side" split-tunnel
  + Add support to main Nortel authentication modes:
    a) "User Name and Password Authentication"
    b) "Group Password Authentication"
    c) "Response Only Token"
    d) "Response Only Token" with split PIN and Token fields
* Wed Aug 26 2009 tittiatcoke@gmail.com
- adjusted group to Productivity/Networking/Security
* Sat Jul 18 2009 tittiatcoke@gmail.com
- disabled the patch to send intial packages twice. This does not
  always work.
* Thu Jan 29 2009 seife@suse.de
- fix segfault in the non-nortel case (bnc#468789)
* Thu Jan 29 2009 seife@suse.de
- update the nortel-grouppasswdauth patch.
  ATTENTION! nortel users have to change "Nortel Auth Mode" to
  "IKE Authmode" in their config file.
- add a patch to send initial packages twice, makes connection
  setup more robust against packet loss
* Sun Jan 18 2009 seife@suse.de
- replace vpnc-nortel-grouppasswordauth.diff with the patch that's
  scheduled for upstream inclusion
* Thu Jan  8 2009 seife@suse.de
- fix rpmlint warnings
* Mon Jan  5 2009 seife@suse.de
- add vpnc-nortel-attributes.diff, to accept split tunnel configs
  from the server
* Mon Jan  5 2009 seife@suse.de
- update to current SVN, using the "nortel" branch.
- add a patch for nortel group password authentication
* Thu Jan 17 2008 lmuelle@suse.de
- Use the real FULL_SCRIPTNAME.
* Mon Jan 14 2008 lmuelle@suse.de
- Update to version 0.5.1.
  + Link against -lcrypto instead of -lssl.
  + Fixed crashes on 64bit platforms.
  + Dead-Peer-Detection support.
  + Hybrid-Auth support.
  + Rekeying support; [#134480].
- Use upstream default location for vpnc-script.
* Sat Nov 11 2006 aj@suse.de
- Fix permissions of man files.
- Compile with RPM_OPT_FLAGS.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Aug 11 2005 lmuelle@suse.de
- Install the example configuration as example.conf in the doc dir.
* Wed Aug 10 2005 lmuelle@suse.de
- Install vpnc.conf no longer as default.conf while keeping default.conf as
  %%config(noreplace) and %%ghost in the package list; [#103856].
* Thu May 19 2005 lmuelle@suse.de
- Update to version 0.3.3; [#72234].
* Tue Nov 23 2004 lmuelle@suse.de
- Update to version 0.3.2.
- Remove most parts of the vpnc-connect diff, [#46931].
* Thu Oct 14 2004 mc@suse.de
- removed depcomp from filelist [#47074]
* Sat Aug  7 2004 lmuelle@suse.de
- Update to version 0.2-rm+zomb.1; [#43525].
* Mon Jul 26 2004 ro@suse.de
- added libgcrypt-devel, libgpg-error-devel to neededforbuild
* Sat May  8 2004 lmuelle@suse.de
- Update to version 0.2-rm+zomb-pre9.
* Fri Apr 16 2004 lmuelle@suse.de
- add man page and connect and disconnect script patches provided by Eduard
  Bloch <blade at debian dot org>
- add /etc/vpnc directory for additional configuration files
- rename /etc/wlan.conf to /etc/vpnc/default.conf
* Mon Apr 12 2004 lmuelle@suse.de
- inital SuSE RPM
